function [residual, g1, g2, g3] = testdynare_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(157, 1);
cgamma__ = 1+params(26)/100;
crealrate__ = 1+params(110)/100;
cbetabar__ = params(42)/crealrate__;
clandap__ = params(17);
cik__ = cgamma__*(1-(1-params(14))/cgamma__);
cikbar__ = 1-(1-params(14))/cgamma__;
cky__ = params(4)/cik__;
crk__ = params(14)+(params(43)/cbetabar__-1)/(1-params(50));
calfa__ = clandap__/params(17)*crk__*cky__;
clabshare__ = 1-calfa__;
cwly__ = clabshare__-params(51);
ctauwf__ = params(51)/cwly__;
ctauwh__ = params(52)/cwly__;
cnprofy__ = 1-clabshare__-params(14)*cky__;
ctaun__ = (params(5)-params(50)*cnprofy__)/cwly__;
ccy__ = 1-params(28)-params(4);
crkky__ = crk__*cky__;
cwhlc__ = cky__*crk__*(1-calfa__)*(1-ctauwh__-ctaun__)/(1+params(49))*1/params(33)/calfa__/ccy__;
cpie__ = 1+params(7)/100;
cr__ = crealrate__*cpie__;
conster__ = 100*(cr__-1);
cpbgov__ = (1+params(42)*params(40)/cr__-params(42))/(1-params(42)/cr__*(1-params(40)));
crbgovncr__ = 1;
cmubgov__ = params(42)/(cr__-params(42)*(1-params(40)));
cpdy__ = (-(crealrate__/cgamma__-1))*params(41);
cdy__ = params(41)*(1-1/(cgamma__*cpie__));
cmawpr__ = params(25)-params(10);
cmappr__ = params(24)-params(11);
cthetabgovsrgg__ = (-params(75))*(1-params(72));
cthetabgovsrtt__ = (-params(80))*(1-params(77));
cthetabgovsrt__ = params(85)*(1-params(82));
cthetabgovsrtauc__ = params(90)*(1-params(87));
cthetabgovsrtaun__ = params(95)*(1-params(92));
cthetabgovsrtauwh__ = params(100)*(1-params(97));
cthetabgovsrtauwf__ = params(105)*(1-params(102));
constedy__ = 100*cdy__;
T124 = crealrate__/cgamma__;
T130 = 1/(cgamma__*cpie__);
T204 = 1/(params(12)/(1-params(12)));
T237 = params(16)/cgamma__;
T238 = 1-T237;
T244 = params(15)*params(16)/cgamma__;
T266 = 1+params(40)/cpbgov__-params(40);
T275 = (1-params(42))/cpbgov__;
T330 = (1-params(15))/T238;
T357 = cgamma__^2;
T359 = T357*params(13);
T380 = crealrate__*params(41)/cgamma__;
T417 = cthetabgovsrgg__/params(41);
T439 = cthetabgovsrtt__/params(41);
T459 = cthetabgovsrt__/params(41);
T479 = cthetabgovsrtauc__/params(41);
T499 = cthetabgovsrtaun__/params(41);
T519 = cthetabgovsrtauwh__/params(41);
T539 = cthetabgovsrtauwf__/params(41);
T614 = 1/(1+cbetabar__*cgamma__);
T749 = 1/(1+cbetabar__*cgamma__*params(30));
T770 = (1-params(31))*(1-cbetabar__*cgamma__*params(31))/params(31)/(1+(clandap__-1)*params(2));
T779 = cbetabar__*cgamma__/(1+cbetabar__*cgamma__);
T822 = (1-params(19))*(1-cbetabar__*cgamma__*params(19))/((1+cbetabar__*cgamma__)*params(19))*1/(1+(params(33)-1)*params(1));
T1160 = (1-params(45))*(1-cgamma__*cbetabar__*params(45))/params(45);
lhs =y(95);
rhs =y(79)-y(141);
residual(1)= lhs-rhs;
lhs =y(68);
rhs =calfa__*y(134)+(1-calfa__)*(y(143)+y(151));
residual(2)= lhs-rhs;
lhs =y(133);
rhs =y(134)*T204;
residual(3)= lhs-rhs;
lhs =y(134);
rhs =y(143)+y(151)+y(142)-y(135);
residual(4)= lhs-rhs;
lhs =y(135);
rhs =y(133)+y(34)-y(78);
residual(5)= lhs-rhs;
lhs =y(139);
rhs =params(42)*(y(230)+y(144)-params(15)*y(213)-y(69))-params(111)*(1-params(42))*y(127)/params(41);
residual(6)= lhs-rhs;
lhs =y(139)*T238;
rhs =(-params(15))*y(138)+T244*(y(35)-y(78))+y(142)*(params(15)-1)*cwhlc__-T238*y(149)/(1+params(49));
residual(7)= lhs-rhs;
lhs =y(126);
rhs =params(42)*(y(230)-params(15)*y(213)-y(139))/cr__*T266-params(42)*y(69)/cpbgov__+params(42)*(1-params(40))/cr__*y(227)-T275*(y(139)+params(111)*y(127)/params(41));
residual(8)= lhs-rhs;
lhs =y(139);
rhs =params(42)*crbgovncr__*(y(230)+y(125)-params(15)*y(213)-y(69))-params(42)*crbgovncr__*(1-params(40))*cmubgov__*(y(226)-y(125))-(1-params(42))*params(111)*y(127)/params(41);
residual(9)= lhs-rhs;
lhs =y(124)-y(125);
rhs =(1-params(40))/(cgamma__*cpie__)*(y(31)-y(125));
residual(10)= lhs-rhs;
lhs =y(141);
rhs =ccy__*y(138)+params(4)*y(140)+y(70)+params(29)*y(145)+y(133)*crkky__;
residual(11)= lhs-rhs;
lhs =y(141);
rhs =params(17)*(y(68)+calfa__*y(135)+(1-calfa__)*y(142));
residual(12)= lhs-rhs;
lhs =T330*(y(138)-T237*(y(35)-y(78)))+y(142)*(params(15)-1)*cwhlc__/T238+y(142)*params(32);
rhs =y(143)+y(139)-(y(155)+y(153))/(1-ctauwh__-ctaun__);
residual(13)= lhs-rhs;
lhs =y(136);
rhs =(1-cikbar__)*(y(34)-y(78))+y(140)*cikbar__+cikbar__*(1+cbetabar__*cgamma__)*T359*y(71);
residual(14)= lhs-rhs;
lhs =cnprofy__*y(132);
rhs =y(141)-cwly__*(y(151)+(1+ctauwf__)*(y(143)+y(142)))-y(133)*crkky__-params(14)*cky__*(y(34)-y(78));
residual(15)= lhs-rhs;
lhs =y(127);
rhs =params(29)*y(145)+T124*(y(32)-y(78))+y(31)*T380+params(53)*y(147)-(y(129)+y(141)*params(44)+cwly__*(y(151)+y(155)+y(153)+(y(143)+y(142))*(ctauwf__+ctauwh__+ctaun__))+ccy__*(y(149)+params(49)*y(138))+cnprofy__*(params(50)*y(132)+y(157)));
residual(16)= lhs-rhs;
lhs =y(146);
rhs =params(72)*y(38)+T417*(y(32)-y(128))+(1-params(73))*x(it_, 8)+params(73)*y(47);
residual(17)= lhs-rhs;
lhs =y(145);
rhs =y(146)+y(141)*params(74);
residual(18)= lhs-rhs;
lhs =y(148);
rhs =params(77)*y(39)+(y(32)-y(128))*T439+(1-params(78))*x(it_, 9)+params(78)*y(48);
residual(19)= lhs-rhs;
lhs =y(147);
rhs =y(148)+y(141)*params(79);
residual(20)= lhs-rhs;
lhs =y(130);
rhs =params(82)*y(33)+(y(32)-y(128))*T459+(1-params(83))*x(it_, 10)+params(83)*y(49);
residual(21)= lhs-rhs;
lhs =y(129);
rhs =y(130)+y(141)*params(84);
residual(22)= lhs-rhs;
lhs =y(150);
rhs =params(87)*y(40)+(y(32)-y(128))*T479+(1-params(88))*x(it_, 11)+params(88)*y(50);
residual(23)= lhs-rhs;
lhs =y(149);
rhs =y(150)+y(141)*params(89);
residual(24)= lhs-rhs;
lhs =y(154);
rhs =params(92)*y(42)+(y(32)-y(128))*T499+(1-params(93))*x(it_, 12)+params(93)*y(51);
residual(25)= lhs-rhs;
lhs =y(153);
rhs =y(154)+y(141)*params(94);
residual(26)= lhs-rhs;
lhs =y(156);
rhs =params(97)*y(43)+(y(32)-y(128))*T519+(1-params(98))*x(it_, 13)+params(98)*y(52);
residual(27)= lhs-rhs;
lhs =y(155);
rhs =y(156)+y(141)*params(99);
residual(28)= lhs-rhs;
lhs =y(152);
rhs =params(102)*y(41)+(y(32)-y(128))*T539+(1-params(103))*x(it_, 14)+params(103)*y(53);
residual(29)= lhs-rhs;
lhs =y(151);
rhs =y(152)+y(141)*params(104);
residual(30)= lhs-rhs;
residual(31) = y(157);
lhs =y(128);
rhs =y(121);
residual(32)= lhs-rhs;
lhs =y(131);
rhs =params(29)*y(145)-y(129)-params(53)*y(147)-cpdy__*y(141)-y(141)*params(44);
residual(33)= lhs-rhs;
lhs =y(86);
rhs =calfa__*y(89)+(1-calfa__)*(y(84)+y(109))-y(68);
residual(34)= lhs-rhs;
lhs =y(88);
rhs =T204*y(89);
residual(35)= lhs-rhs;
lhs =y(89);
rhs =y(109)+y(84)+y(93)-y(90);
residual(36)= lhs-rhs;
lhs =y(90);
rhs =y(88)+y(17)-y(78);
residual(37)= lhs-rhs;
lhs =y(92);
rhs =params(43)*(y(215)-params(15)*y(213))-y(82)+(1-params(50))*cbetabar__*crk__*y(219)+cbetabar__*(1-params(14))*y(220)-(1-params(43))*params(112)*y(91)-crk__*cbetabar__*(1-params(14))*y(225);
residual(38)= lhs-rhs;
lhs =y(81);
rhs =y(71)+T614*(y(14)+cbetabar__*cgamma__*y(214)+y(92)*1/T359-y(78)+y(213)*cbetabar__*cgamma__);
residual(39)= lhs-rhs;
lhs =y(140);
rhs =y(71)+T614*(y(213)*cbetabar__*cgamma__+y(36)+cbetabar__*cgamma__*y(231)+1/T359*y(137)-y(78));
residual(40)= lhs-rhs;
lhs =y(137);
rhs =params(43)*(y(230)-params(15)*y(213))-y(139)+(1-params(50))*cbetabar__*crk__*y(228)+cbetabar__*(1-params(14))*y(229)-y(136)*(1-params(43))*params(112)-crk__*cbetabar__*(1-params(14))*y(232);
residual(41)= lhs-rhs;
lhs =y(91);
rhs =(1-cikbar__)*(y(17)-y(78))+cikbar__*y(81)+y(71)*params(13)*cikbar__*(1+cbetabar__*cgamma__)*T357;
residual(42)= lhs-rhs;
lhs =y(82);
rhs =params(42)*(y(215)+y(96)-y(216)-params(15)*y(213)-y(69))-params(111)*(1-params(42))*y(119)/params(41);
residual(43)= lhs-rhs;
lhs =y(102);
rhs =T266*params(42)*(y(215)-params(15)*y(213)-y(82)-y(216))/cr__-params(42)*y(69)/cpbgov__+params(42)*(1-params(40))/cr__*y(224)-T275*(y(82)+params(111)*y(119)/params(41));
residual(44)= lhs-rhs;
lhs =y(82);
rhs =params(42)*crbgovncr__*(y(215)+y(101)-y(216)-params(15)*y(213)-y(69))-params(42)*crbgovncr__*(1-params(40))*cmubgov__*(y(223)-y(101))-(1-params(42))*params(111)*y(119)/params(41);
residual(45)= lhs-rhs;
lhs =y(100)-y(101);
rhs =(1-params(40))/(cgamma__*cpie__)*(y(20)-y(101));
residual(46)= lhs-rhs;
lhs =T238*y(82);
rhs =(-params(15))*y(80)+T244*(y(13)-y(78))+(params(15)-1)*cwhlc__*y(93)-T238*y(105)/(1+params(49));
residual(47)= lhs-rhs;
lhs =y(79);
rhs =y(70)+ccy__*y(80)+params(4)*y(81)+params(29)*y(103)+crkky__*y(88);
residual(48)= lhs-rhs;
lhs =y(158);
rhs =y(70)+ccy__*y(80)+params(4)*y(81)+params(29)*y(103);
residual(49)= lhs-rhs;
lhs =y(79);
rhs =params(17)*(y(68)+calfa__*y(90)+(1-calfa__)*y(93));
residual(50)= lhs-rhs;
lhs =y(83)-y(77);
rhs =T749*(cbetabar__*cgamma__*(y(216)-y(212))+params(30)*(y(15)-y(77))+cbetabar__*cgamma__*params(30)*(y(212)-y(77))+y(86)*T770)+y(73);
residual(51)= lhs-rhs;
lhs =y(84);
rhs =T614*y(16)+T779*y(217)+y(15)*params(18)/(1+cbetabar__*cgamma__)-y(83)*(1+cbetabar__*cgamma__*params(18))/(1+cbetabar__*cgamma__)+T614*(y(213)*cbetabar__*cgamma__-y(78)-cbetabar__*cgamma__*y(218)+y(87))+y(216)*T779-y(212)*cbetabar__*cgamma__*(1-params(18))/(1+cbetabar__*cgamma__)+y(77)*(1-params(18))/(1+cbetabar__*cgamma__)+T822*(y(85)-y(84))+y(74);
residual(52)= lhs-rhs;
lhs =y(87);
rhs =y(78);
residual(53)= lhs-rhs;
lhs =T330*(y(80)-T237*(y(13)-y(78)))+(params(15)-1)*cwhlc__/T238*y(93)+params(32)*y(93);
rhs =y(82)+y(85)-(y(107)+y(111))/(1-ctauwh__-ctaun__);
residual(54)= lhs-rhs;
lhs =y(96)-y(77);
rhs =(1-x(it_, 19))*((y(83)-y(77))*params(34)*(1-params(37))+(y(79)-y(141))*(1-params(37))*params(36)+params(35)*(y(37)+y(79)-y(141)-y(12))+params(37)*(y(19)-y(11))+y(72))-x(it_, 19)*x(it_, 18)+y(1);
residual(55)= lhs-rhs;
lhs =y(77)-y(11)*0.999;
rhs =x(it_, 16)+params(23)*(y(11)-0.999*y(44));
residual(56)= lhs-rhs;
lhs =y(63);
rhs =y(1)*params(71)+x(it_, 17);
residual(57)= lhs-rhs;
lhs =y(67);
rhs =y(1)+y(77)+y(72)-params(37)*y(11)-y(77)*params(34)*(1-params(37));
residual(58)= lhs-rhs;
lhs =y(64);
rhs =y(211);
residual(59)= lhs-rhs;
lhs =y(68);
rhs =params(38)*y(2)+x(it_, 1);
residual(60)= lhs-rhs;
lhs =y(69);
rhs =params(39)*y(3)+x(it_, 2);
residual(61)= lhs-rhs;
lhs =y(70);
rhs =params(20)*y(4)+x(it_, 3)+x(it_, 1)*params(3);
residual(62)= lhs-rhs;
lhs =y(71);
rhs =params(21)*y(5)+x(it_, 4);
residual(63)= lhs-rhs;
lhs =y(72);
rhs =params(22)*y(6)+x(it_, 5);
residual(64)= lhs-rhs;
lhs =y(73);
rhs =params(24)*y(7)+y(76)-cmappr__*y(10);
residual(65)= lhs-rhs;
lhs =y(76);
rhs =x(it_, 6);
residual(66)= lhs-rhs;
lhs =y(74);
rhs =params(25)*y(8)+y(75)-cmawpr__*y(9);
residual(67)= lhs-rhs;
lhs =y(75);
rhs =x(it_, 7);
residual(68)= lhs-rhs;
residual(69) = y(78);
lhs =cnprofy__*y(120);
rhs =y(79)-cwly__*(y(109)+(1+ctauwf__)*(y(84)+y(93)))-crkky__*y(88)-params(14)*cky__*(y(17)-y(78));
residual(70)= lhs-rhs;
lhs =y(119);
rhs =params(29)*y(103)+T124*(y(29)-y(78))+T380*(y(20)-y(83))+params(53)*y(116)-(y(114)+y(79)*params(44)+cwly__*(y(109)+y(111)+y(107)+(ctauwf__+ctauwh__+ctaun__)*(y(84)+y(93)))+ccy__*(y(105)+params(49)*y(80))+cnprofy__*(params(50)*y(120)+y(113)));
residual(71)= lhs-rhs;
lhs =y(104);
rhs =(1-params(73))*x(it_, 8)+params(72)*y(21)+T417*(y(29)-y(121))+params(73)*y(47);
residual(72)= lhs-rhs;
lhs =y(103);
rhs =y(104)+y(79)*params(74);
residual(73)= lhs-rhs;
lhs =y(117);
rhs =(1-params(78))*x(it_, 9)+params(77)*y(28)+T439*(y(29)-y(121))+params(78)*y(48);
residual(74)= lhs-rhs;
lhs =y(116);
rhs =y(117)+y(79)*params(79);
residual(75)= lhs-rhs;
lhs =y(115);
rhs =(1-params(83))*x(it_, 10)+params(82)*y(27)+T459*(y(29)-y(121))+params(83)*y(49);
residual(76)= lhs-rhs;
lhs =y(114);
rhs =y(115)+y(79)*params(84);
residual(77)= lhs-rhs;
lhs =y(106);
rhs =(1-params(88))*x(it_, 11)+params(87)*y(22)+T479*(y(29)-y(121))+params(88)*y(50);
residual(78)= lhs-rhs;
lhs =y(105);
rhs =y(106)+y(79)*params(89);
residual(79)= lhs-rhs;
lhs =y(112);
rhs =(1-params(93))*x(it_, 12)+params(92)*y(26)+T499*(y(29)-y(121))+params(93)*y(51);
residual(80)= lhs-rhs;
lhs =y(111);
rhs =y(112)+y(79)*params(94);
residual(81)= lhs-rhs;
lhs =y(108);
rhs =(1-params(98))*x(it_, 13)+params(97)*y(23)+T519*(y(29)-y(121))+params(98)*y(52);
residual(82)= lhs-rhs;
lhs =y(107);
rhs =y(108)+y(79)*params(99);
residual(83)= lhs-rhs;
lhs =y(110);
rhs =(1-params(103))*x(it_, 14)+params(102)*y(25)+T539*(y(29)-y(121))+params(103)*y(53);
residual(84)= lhs-rhs;
lhs =y(109);
rhs =y(110)+y(79)*params(104);
residual(85)= lhs-rhs;
residual(86) = y(113);
lhs =y(118);
rhs =params(29)*y(103)+params(53)*y(116)-(y(114)+y(79)*params(44)+cwly__*(y(109)+y(111)+y(107)+(ctauwf__+ctauwh__+ctaun__)*(y(84)+y(93)))+ccy__*(y(105)+params(49)*y(80))+cnprofy__*(params(50)*y(120)+y(113)))-cpdy__*y(79);
residual(87)= lhs-rhs;
residual(88) = y(121);
lhs =y(123);
rhs =params(107)*y(30)+y(122);
residual(89)= lhs-rhs;
lhs =y(122);
rhs =y(122)*params(108)+x(it_, 15);
residual(90)= lhs-rhs;
lhs =y(99);
rhs =y(83)+y(15)+y(45)+y(46);
residual(91)= lhs-rhs;
lhs =y(98);
rhs =4*y(83);
residual(92)= lhs-rhs;
lhs =y(97);
rhs =4*y(96);
residual(93)= lhs-rhs;
lhs =y(57);
rhs =params(26)+cgamma__*(y(78)+y(79)-y(12));
residual(94)= lhs-rhs;
lhs =y(60);
rhs =params(26)+y(78)+y(80)-y(13);
residual(95)= lhs-rhs;
lhs =y(61);
rhs =params(26)+y(78)+y(81)-y(14);
residual(96)= lhs-rhs;
lhs =y(56);
rhs =params(7)+y(83);
residual(97)= lhs-rhs;
lhs =y(55);
rhs =4*(y(96)+conster__);
residual(98)= lhs-rhs;
lhs =y(62);
rhs =params(26)+y(78)+y(84)-y(16)+(y(109)-y(24))/(1-ctauwf__);
residual(99)= lhs-rhs;
lhs =y(94)-y(18);
rhs =cbetabar__*cgamma__*(y(221)-y(94))+T1160*(y(93)-y(94));
residual(100)= lhs-rhs;
lhs =y(54);
rhs =y(94)+params(6);
residual(101)= lhs-rhs;
lhs =y(66);
rhs =4*(conster__+y(222));
residual(102)= lhs-rhs;
lhs =y(65);
rhs =4*(conster__+y(222));
residual(103)= lhs-rhs;
lhs =y(160)/4;
rhs =y(159)+params(8);
residual(104)= lhs-rhs;
lhs =y(159);
rhs =0.05*(y(252)+y(253)+y(254)+y(255)+y(256)+y(257)+y(258)+y(259)+y(260)+y(261)+y(262)+y(263)+y(264)+y(265)+y(266)+y(267)+y(268)+y(269)+y(270)+y(271));
residual(105)= lhs-rhs;
lhs =y(161);
rhs =y(160);
residual(106)= lhs-rhs;
lhs =y(58);
rhs =y(119)+constedy__-T130*(y(29)+params(41)*(y(79)*(cgamma__*cpie__-1)-(y(78)+y(83))));
residual(107)= lhs-rhs;
lhs =y(59);
rhs =y(119)/params(41)+params(48);
residual(108)= lhs-rhs;
lhs =y(162);
rhs =y(216);
residual(109)= lhs-rhs;
lhs =y(163);
rhs =y(233);
residual(110)= lhs-rhs;
lhs =y(164);
rhs =y(234);
residual(111)= lhs-rhs;
lhs =y(165);
rhs =y(235);
residual(112)= lhs-rhs;
lhs =y(166);
rhs =y(236);
residual(113)= lhs-rhs;
lhs =y(167);
rhs =y(237);
residual(114)= lhs-rhs;
lhs =y(168);
rhs =y(238);
residual(115)= lhs-rhs;
lhs =y(169);
rhs =y(239);
residual(116)= lhs-rhs;
lhs =y(170);
rhs =y(240);
residual(117)= lhs-rhs;
lhs =y(171);
rhs =y(241);
residual(118)= lhs-rhs;
lhs =y(172);
rhs =y(242);
residual(119)= lhs-rhs;
lhs =y(173);
rhs =y(243);
residual(120)= lhs-rhs;
lhs =y(174);
rhs =y(244);
residual(121)= lhs-rhs;
lhs =y(175);
rhs =y(245);
residual(122)= lhs-rhs;
lhs =y(176);
rhs =y(246);
residual(123)= lhs-rhs;
lhs =y(177);
rhs =y(247);
residual(124)= lhs-rhs;
lhs =y(178);
rhs =y(248);
residual(125)= lhs-rhs;
lhs =y(179);
rhs =y(249);
residual(126)= lhs-rhs;
lhs =y(180);
rhs =y(250);
residual(127)= lhs-rhs;
lhs =y(181);
rhs =y(251);
residual(128)= lhs-rhs;
lhs =y(182);
rhs =y(252);
residual(129)= lhs-rhs;
lhs =y(183);
rhs =y(253);
residual(130)= lhs-rhs;
lhs =y(184);
rhs =y(254);
residual(131)= lhs-rhs;
lhs =y(185);
rhs =y(255);
residual(132)= lhs-rhs;
lhs =y(186);
rhs =y(256);
residual(133)= lhs-rhs;
lhs =y(187);
rhs =y(257);
residual(134)= lhs-rhs;
lhs =y(188);
rhs =y(258);
residual(135)= lhs-rhs;
lhs =y(189);
rhs =y(259);
residual(136)= lhs-rhs;
lhs =y(190);
rhs =y(260);
residual(137)= lhs-rhs;
lhs =y(191);
rhs =y(261);
residual(138)= lhs-rhs;
lhs =y(192);
rhs =y(262);
residual(139)= lhs-rhs;
lhs =y(193);
rhs =y(263);
residual(140)= lhs-rhs;
lhs =y(194);
rhs =y(264);
residual(141)= lhs-rhs;
lhs =y(195);
rhs =y(265);
residual(142)= lhs-rhs;
lhs =y(196);
rhs =y(266);
residual(143)= lhs-rhs;
lhs =y(197);
rhs =y(267);
residual(144)= lhs-rhs;
lhs =y(198);
rhs =y(268);
residual(145)= lhs-rhs;
lhs =y(199);
rhs =y(269);
residual(146)= lhs-rhs;
lhs =y(200);
rhs =y(270);
residual(147)= lhs-rhs;
lhs =y(201);
rhs =y(11);
residual(148)= lhs-rhs;
lhs =y(202);
rhs =y(15);
residual(149)= lhs-rhs;
lhs =y(203);
rhs =y(45);
residual(150)= lhs-rhs;
lhs =y(204);
rhs =x(it_, 8);
residual(151)= lhs-rhs;
lhs =y(205);
rhs =x(it_, 9);
residual(152)= lhs-rhs;
lhs =y(206);
rhs =x(it_, 10);
residual(153)= lhs-rhs;
lhs =y(207);
rhs =x(it_, 11);
residual(154)= lhs-rhs;
lhs =y(208);
rhs =x(it_, 12);
residual(155)= lhs-rhs;
lhs =y(209);
rhs =x(it_, 13);
residual(156)= lhs-rhs;
lhs =y(210);
rhs =x(it_, 14);
residual(157)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(157, 290);

  %
  % Jacobian matrix
  %

T3 = (-1);
T1628 = (-((1-params(40))/(cgamma__*cpie__)));
T1639 = 1/(1-ctauwh__-ctaun__);
  g1(1,79)=T3;
  g1(1,95)=1;
  g1(1,141)=1;
  g1(2,68)=1;
  g1(2,134)=(-calfa__);
  g1(2,143)=(-(1-calfa__));
  g1(2,151)=(-(1-calfa__));
  g1(3,133)=1;
  g1(3,134)=(-T204);
  g1(4,134)=1;
  g1(4,135)=1;
  g1(4,142)=T3;
  g1(4,143)=T3;
  g1(4,151)=T3;
  g1(5,78)=1;
  g1(5,133)=T3;
  g1(5,135)=1;
  g1(5,34)=T3;
  g1(6,69)=params(42);
  g1(6,213)=(-(params(42)*(-params(15))));
  g1(6,127)=params(111)*(1-params(42))*1/params(41);
  g1(6,139)=1;
  g1(6,230)=(-params(42));
  g1(6,144)=(-params(42));
  g1(7,78)=T244;
  g1(7,35)=(-T244);
  g1(7,138)=params(15);
  g1(7,139)=T238;
  g1(7,142)=(-((params(15)-1)*cwhlc__));
  g1(7,149)=T238/(1+params(49));
  g1(8,69)=params(42)/cpbgov__;
  g1(8,213)=(-(T266*params(42)*(-params(15))/cr__));
  g1(8,126)=1;
  g1(8,227)=(-(params(42)*(1-params(40))/cr__));
  g1(8,127)=T275*params(111)/params(41);
  g1(8,139)=(-(T266*(-params(42))/cr__-T275));
  g1(8,230)=(-(params(42)/cr__*T266));
  g1(9,69)=params(42)*crbgovncr__;
  g1(9,213)=(-((-params(15))*params(42)*crbgovncr__));
  g1(9,125)=(-(params(42)*crbgovncr__-(-(params(42)*crbgovncr__*(1-params(40))*cmubgov__))));
  g1(9,226)=params(42)*crbgovncr__*(1-params(40))*cmubgov__;
  g1(9,127)=(1-params(42))*params(111)/params(41);
  g1(9,139)=1;
  g1(9,230)=(-(params(42)*crbgovncr__));
  g1(10,31)=T1628;
  g1(10,124)=1;
  g1(10,125)=T3-T1628;
  g1(11,70)=T3;
  g1(11,133)=(-crkky__);
  g1(11,138)=(-ccy__);
  g1(11,140)=(-params(4));
  g1(11,141)=1;
  g1(11,145)=(-params(29));
  g1(12,68)=(-params(17));
  g1(12,135)=(-(params(17)*calfa__));
  g1(12,141)=1;
  g1(12,142)=(-(params(17)*(1-calfa__)));
  g1(13,78)=T237*T330;
  g1(13,35)=T330*(-T237);
  g1(13,138)=T330;
  g1(13,139)=T3;
  g1(13,142)=(params(15)-1)*cwhlc__/T238+params(32);
  g1(13,143)=T3;
  g1(13,153)=T1639;
  g1(13,155)=T1639;
  g1(14,71)=(-(cikbar__*(1+cbetabar__*cgamma__)*T359));
  g1(14,78)=1-cikbar__;
  g1(14,34)=(-(1-cikbar__));
  g1(14,136)=1;
  g1(14,140)=(-cikbar__);
  g1(15,78)=(-(params(14)*cky__));
  g1(15,132)=cnprofy__;
  g1(15,133)=crkky__;
  g1(15,34)=params(14)*cky__;
  g1(15,141)=T3;
  g1(15,142)=cwly__*(1+ctauwf__);
  g1(15,143)=cwly__*(1+ctauwf__);
  g1(15,151)=cwly__;
  g1(16,78)=T124;
  g1(16,31)=(-T380);
  g1(16,32)=(-T124);
  g1(16,127)=1;
  g1(16,129)=1;
  g1(16,132)=params(50)*cnprofy__;
  g1(16,138)=params(49)*ccy__;
  g1(16,141)=params(44);
  g1(16,142)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(16,143)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(16,145)=(-params(29));
  g1(16,147)=(-params(53));
  g1(16,149)=ccy__;
  g1(16,151)=cwly__;
  g1(16,153)=cwly__;
  g1(16,155)=cwly__;
  g1(16,157)=cnprofy__;
  g1(17,32)=(-T417);
  g1(17,128)=T417;
  g1(17,38)=(-params(72));
  g1(17,146)=1;
  g1(17,279)=(-(1-params(73)));
  g1(17,47)=(-params(73));
  g1(18,141)=(-params(74));
  g1(18,145)=1;
  g1(18,146)=T3;
  g1(19,32)=(-T439);
  g1(19,128)=T439;
  g1(19,39)=(-params(77));
  g1(19,148)=1;
  g1(19,280)=(-(1-params(78)));
  g1(19,48)=(-params(78));
  g1(20,141)=(-params(79));
  g1(20,147)=1;
  g1(20,148)=T3;
  g1(21,32)=(-T459);
  g1(21,128)=T459;
  g1(21,33)=(-params(82));
  g1(21,130)=1;
  g1(21,281)=(-(1-params(83)));
  g1(21,49)=(-params(83));
  g1(22,129)=1;
  g1(22,130)=T3;
  g1(22,141)=(-params(84));
  g1(23,32)=(-T479);
  g1(23,128)=T479;
  g1(23,40)=(-params(87));
  g1(23,150)=1;
  g1(23,282)=(-(1-params(88)));
  g1(23,50)=(-params(88));
  g1(24,141)=(-params(89));
  g1(24,149)=1;
  g1(24,150)=T3;
  g1(25,32)=(-T499);
  g1(25,128)=T499;
  g1(25,42)=(-params(92));
  g1(25,154)=1;
  g1(25,283)=(-(1-params(93)));
  g1(25,51)=(-params(93));
  g1(26,141)=(-params(94));
  g1(26,153)=1;
  g1(26,154)=T3;
  g1(27,32)=(-T519);
  g1(27,128)=T519;
  g1(27,43)=(-params(97));
  g1(27,156)=1;
  g1(27,284)=(-(1-params(98)));
  g1(27,52)=(-params(98));
  g1(28,141)=(-params(99));
  g1(28,155)=1;
  g1(28,156)=T3;
  g1(29,32)=(-T539);
  g1(29,128)=T539;
  g1(29,41)=(-params(102));
  g1(29,152)=1;
  g1(29,285)=(-(1-params(103)));
  g1(29,53)=(-params(103));
  g1(30,141)=(-params(104));
  g1(30,151)=1;
  g1(30,152)=T3;
  g1(31,157)=1;
  g1(32,121)=T3;
  g1(32,128)=1;
  g1(33,129)=1;
  g1(33,131)=1;
  g1(33,141)=(-((-cpdy__)-params(44)));
  g1(33,145)=(-params(29));
  g1(33,147)=params(53);
  g1(34,68)=1;
  g1(34,84)=(-(1-calfa__));
  g1(34,86)=1;
  g1(34,89)=(-calfa__);
  g1(34,109)=(-(1-calfa__));
  g1(35,88)=1;
  g1(35,89)=(-T204);
  g1(36,84)=T3;
  g1(36,89)=1;
  g1(36,90)=1;
  g1(36,93)=T3;
  g1(36,109)=T3;
  g1(37,78)=1;
  g1(37,88)=T3;
  g1(37,90)=1;
  g1(37,17)=T3;
  g1(38,213)=(-(params(43)*(-params(15))));
  g1(38,82)=1;
  g1(38,215)=(-params(43));
  g1(38,219)=(-((1-params(50))*cbetabar__*crk__));
  g1(38,91)=(1-params(43))*params(112);
  g1(38,92)=1;
  g1(38,220)=(-(cbetabar__*(1-params(14))));
  g1(38,225)=crk__*cbetabar__*(1-params(14));
  g1(39,71)=T3;
  g1(39,78)=T614;
  g1(39,213)=(-(cbetabar__*cgamma__*T614));
  g1(39,14)=(-T614);
  g1(39,81)=1;
  g1(39,214)=(-(cbetabar__*cgamma__*T614));
  g1(39,92)=(-(T614*1/T359));
  g1(40,71)=T3;
  g1(40,78)=T614;
  g1(40,213)=(-(cbetabar__*cgamma__*T614));
  g1(40,137)=(-(T614*1/T359));
  g1(40,36)=(-T614);
  g1(40,140)=1;
  g1(40,231)=(-(cbetabar__*cgamma__*T614));
  g1(41,213)=(-(params(43)*(-params(15))));
  g1(41,228)=(-((1-params(50))*cbetabar__*crk__));
  g1(41,136)=(1-params(43))*params(112);
  g1(41,137)=1;
  g1(41,229)=(-(cbetabar__*(1-params(14))));
  g1(41,139)=1;
  g1(41,230)=(-params(43));
  g1(41,232)=crk__*cbetabar__*(1-params(14));
  g1(42,71)=(-(params(13)*cikbar__*(1+cbetabar__*cgamma__)*T357));
  g1(42,78)=1-cikbar__;
  g1(42,81)=(-cikbar__);
  g1(42,17)=(-(1-cikbar__));
  g1(42,91)=1;
  g1(43,69)=params(42);
  g1(43,213)=(-(params(42)*(-params(15))));
  g1(43,82)=1;
  g1(43,215)=(-params(42));
  g1(43,216)=params(42);
  g1(43,96)=(-params(42));
  g1(43,119)=params(111)*(1-params(42))*1/params(41);
  g1(44,69)=params(42)/cpbgov__;
  g1(44,213)=(-(T266*params(42)*(-params(15))/cr__));
  g1(44,82)=(-(T266*(-params(42))/cr__-T275));
  g1(44,215)=(-(params(42)/cr__*T266));
  g1(44,216)=(-(T266*(-params(42))/cr__));
  g1(44,102)=1;
  g1(44,224)=(-(params(42)*(1-params(40))/cr__));
  g1(44,119)=T275*params(111)/params(41);
  g1(45,69)=params(42)*crbgovncr__;
  g1(45,213)=(-((-params(15))*params(42)*crbgovncr__));
  g1(45,82)=1;
  g1(45,215)=(-(params(42)*crbgovncr__));
  g1(45,216)=params(42)*crbgovncr__;
  g1(45,101)=(-(params(42)*crbgovncr__-(-(params(42)*crbgovncr__*(1-params(40))*cmubgov__))));
  g1(45,223)=params(42)*crbgovncr__*(1-params(40))*cmubgov__;
  g1(45,119)=(1-params(42))*params(111)/params(41);
  g1(46,20)=T1628;
  g1(46,100)=1;
  g1(46,101)=T3-T1628;
  g1(47,78)=T244;
  g1(47,13)=(-T244);
  g1(47,80)=params(15);
  g1(47,82)=T238;
  g1(47,93)=(-((params(15)-1)*cwhlc__));
  g1(47,105)=T238/(1+params(49));
  g1(48,70)=T3;
  g1(48,79)=1;
  g1(48,80)=(-ccy__);
  g1(48,81)=(-params(4));
  g1(48,88)=(-crkky__);
  g1(48,103)=(-params(29));
  g1(49,70)=T3;
  g1(49,80)=(-ccy__);
  g1(49,81)=(-params(4));
  g1(49,103)=(-params(29));
  g1(49,158)=1;
  g1(50,68)=(-params(17));
  g1(50,79)=1;
  g1(50,90)=(-(params(17)*calfa__));
  g1(50,93)=(-(params(17)*(1-calfa__)));
  g1(51,73)=T3;
  g1(51,77)=T3-T749*((-params(30))-cbetabar__*cgamma__*params(30));
  g1(51,212)=(-(T749*(cbetabar__*cgamma__*params(30)+(-(cbetabar__*cgamma__)))));
  g1(51,15)=(-(params(30)*T749));
  g1(51,83)=1;
  g1(51,216)=(-(cbetabar__*cgamma__*T749));
  g1(51,86)=(-(T749*T770));
  g1(52,74)=T3;
  g1(52,77)=(-((1-params(18))/(1+cbetabar__*cgamma__)));
  g1(52,212)=cbetabar__*cgamma__*(1-params(18))/(1+cbetabar__*cgamma__);
  g1(52,78)=T614;
  g1(52,213)=(-(cbetabar__*cgamma__*T614));
  g1(52,15)=(-(params(18)/(1+cbetabar__*cgamma__)));
  g1(52,83)=(1+cbetabar__*cgamma__*params(18))/(1+cbetabar__*cgamma__);
  g1(52,216)=(-T779);
  g1(52,16)=(-T614);
  g1(52,84)=1-(-T822);
  g1(52,217)=(-T779);
  g1(52,85)=(-T822);
  g1(52,87)=(-T614);
  g1(52,218)=(-(T614*(-(cbetabar__*cgamma__))));
  g1(53,78)=T3;
  g1(53,87)=1;
  g1(54,78)=T237*T330;
  g1(54,13)=T330*(-T237);
  g1(54,80)=T330;
  g1(54,82)=T3;
  g1(54,85)=T3;
  g1(54,93)=(params(15)-1)*cwhlc__/T238+params(32);
  g1(54,107)=T1639;
  g1(54,111)=T1639;
  g1(55,1)=T3;
  g1(55,72)=(-(1-x(it_, 19)));
  g1(55,11)=(-((1-x(it_, 19))*(-params(37))));
  g1(55,77)=T3-(1-x(it_, 19))*(-(params(34)*(1-params(37))));
  g1(55,12)=(-((1-x(it_, 19))*(-params(35))));
  g1(55,79)=(-((1-x(it_, 19))*((1-params(37))*params(36)+params(35))));
  g1(55,83)=(-((1-x(it_, 19))*params(34)*(1-params(37))));
  g1(55,19)=(-((1-x(it_, 19))*params(37)));
  g1(55,96)=1;
  g1(55,37)=(-((1-x(it_, 19))*params(35)));
  g1(55,141)=(-((1-x(it_, 19))*((-((1-params(37))*params(36)))-params(35))));
  g1(55,289)=x(it_, 19);
  g1(55,290)=(-((-((y(83)-y(77))*params(34)*(1-params(37))+(y(79)-y(141))*(1-params(37))*params(36)+params(35)*(y(37)+y(79)-y(141)-y(12))+params(37)*(y(19)-y(11))+y(72)))-x(it_, 18)));
  g1(56,11)=(-0.999)-params(23);
  g1(56,77)=1;
  g1(56,287)=T3;
  g1(56,44)=(-(params(23)*(-0.999)));
  g1(57,1)=(-params(71));
  g1(57,63)=1;
  g1(57,288)=T3;
  g1(58,1)=T3;
  g1(58,67)=1;
  g1(58,72)=T3;
  g1(58,11)=params(37);
  g1(58,77)=(-(1-params(34)*(1-params(37))));
  g1(59,64)=1;
  g1(59,211)=T3;
  g1(60,2)=(-params(38));
  g1(60,68)=1;
  g1(60,272)=T3;
  g1(61,3)=(-params(39));
  g1(61,69)=1;
  g1(61,273)=T3;
  g1(62,4)=(-params(20));
  g1(62,70)=1;
  g1(62,272)=(-params(3));
  g1(62,274)=T3;
  g1(63,5)=(-params(21));
  g1(63,71)=1;
  g1(63,275)=T3;
  g1(64,6)=(-params(22));
  g1(64,72)=1;
  g1(64,276)=T3;
  g1(65,7)=(-params(24));
  g1(65,73)=1;
  g1(65,10)=cmappr__;
  g1(65,76)=T3;
  g1(66,76)=1;
  g1(66,277)=T3;
  g1(67,8)=(-params(25));
  g1(67,74)=1;
  g1(67,9)=cmawpr__;
  g1(67,75)=T3;
  g1(68,75)=1;
  g1(68,278)=T3;
  g1(69,78)=1;
  g1(70,78)=(-(params(14)*cky__));
  g1(70,79)=T3;
  g1(70,84)=cwly__*(1+ctauwf__);
  g1(70,88)=crkky__;
  g1(70,17)=params(14)*cky__;
  g1(70,93)=cwly__*(1+ctauwf__);
  g1(70,109)=cwly__;
  g1(70,120)=cnprofy__;
  g1(71,78)=T124;
  g1(71,79)=params(44);
  g1(71,80)=params(49)*ccy__;
  g1(71,83)=T380;
  g1(71,84)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(71,93)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(71,20)=(-T380);
  g1(71,103)=(-params(29));
  g1(71,105)=ccy__;
  g1(71,107)=cwly__;
  g1(71,109)=cwly__;
  g1(71,111)=cwly__;
  g1(71,113)=cnprofy__;
  g1(71,114)=1;
  g1(71,116)=(-params(53));
  g1(71,29)=(-T124);
  g1(71,119)=1;
  g1(71,120)=params(50)*cnprofy__;
  g1(72,21)=(-params(72));
  g1(72,104)=1;
  g1(72,29)=(-T417);
  g1(72,121)=T417;
  g1(72,279)=(-(1-params(73)));
  g1(72,47)=(-params(73));
  g1(73,79)=(-params(74));
  g1(73,103)=1;
  g1(73,104)=T3;
  g1(74,28)=(-params(77));
  g1(74,117)=1;
  g1(74,29)=(-T439);
  g1(74,121)=T439;
  g1(74,280)=(-(1-params(78)));
  g1(74,48)=(-params(78));
  g1(75,79)=(-params(79));
  g1(75,116)=1;
  g1(75,117)=T3;
  g1(76,27)=(-params(82));
  g1(76,115)=1;
  g1(76,29)=(-T459);
  g1(76,121)=T459;
  g1(76,281)=(-(1-params(83)));
  g1(76,49)=(-params(83));
  g1(77,79)=(-params(84));
  g1(77,114)=1;
  g1(77,115)=T3;
  g1(78,22)=(-params(87));
  g1(78,106)=1;
  g1(78,29)=(-T479);
  g1(78,121)=T479;
  g1(78,282)=(-(1-params(88)));
  g1(78,50)=(-params(88));
  g1(79,79)=(-params(89));
  g1(79,105)=1;
  g1(79,106)=T3;
  g1(80,26)=(-params(92));
  g1(80,112)=1;
  g1(80,29)=(-T499);
  g1(80,121)=T499;
  g1(80,283)=(-(1-params(93)));
  g1(80,51)=(-params(93));
  g1(81,79)=(-params(94));
  g1(81,111)=1;
  g1(81,112)=T3;
  g1(82,23)=(-params(97));
  g1(82,108)=1;
  g1(82,29)=(-T519);
  g1(82,121)=T519;
  g1(82,284)=(-(1-params(98)));
  g1(82,52)=(-params(98));
  g1(83,79)=(-params(99));
  g1(83,107)=1;
  g1(83,108)=T3;
  g1(84,25)=(-params(102));
  g1(84,110)=1;
  g1(84,29)=(-T539);
  g1(84,121)=T539;
  g1(84,285)=(-(1-params(103)));
  g1(84,53)=(-params(103));
  g1(85,79)=(-params(104));
  g1(85,109)=1;
  g1(85,110)=T3;
  g1(86,113)=1;
  g1(87,79)=(-((-params(44))-cpdy__));
  g1(87,80)=params(49)*ccy__;
  g1(87,84)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(87,93)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(87,103)=(-params(29));
  g1(87,105)=ccy__;
  g1(87,107)=cwly__;
  g1(87,109)=cwly__;
  g1(87,111)=cwly__;
  g1(87,113)=cnprofy__;
  g1(87,114)=1;
  g1(87,116)=(-params(53));
  g1(87,118)=1;
  g1(87,120)=params(50)*cnprofy__;
  g1(88,121)=1;
  g1(89,122)=T3;
  g1(89,30)=(-params(107));
  g1(89,123)=1;
  g1(90,122)=1-params(108);
  g1(90,286)=T3;
  g1(91,15)=T3;
  g1(91,83)=T3;
  g1(91,99)=1;
  g1(91,45)=T3;
  g1(91,46)=T3;
  g1(92,83)=(-4);
  g1(92,98)=1;
  g1(93,96)=(-4);
  g1(93,97)=1;
  g1(94,57)=1;
  g1(94,78)=(-cgamma__);
  g1(94,12)=cgamma__;
  g1(94,79)=(-cgamma__);
  g1(95,60)=1;
  g1(95,78)=T3;
  g1(95,13)=1;
  g1(95,80)=T3;
  g1(96,61)=1;
  g1(96,78)=T3;
  g1(96,14)=1;
  g1(96,81)=T3;
  g1(97,56)=1;
  g1(97,83)=T3;
  g1(98,55)=1;
  g1(98,96)=(-4);
  g1(99,62)=1;
  g1(99,78)=T3;
  g1(99,16)=1;
  g1(99,84)=T3;
  g1(99,24)=(-(T3/(1-ctauwf__)));
  g1(99,109)=(-(1/(1-ctauwf__)));
  g1(100,93)=(-T1160);
  g1(100,18)=T3;
  g1(100,94)=1-((-(cbetabar__*cgamma__))-T1160);
  g1(100,221)=(-(cbetabar__*cgamma__));
  g1(101,54)=1;
  g1(101,94)=T3;
  g1(102,66)=1;
  g1(102,222)=(-4);
  g1(103,65)=1;
  g1(103,222)=(-4);
  g1(104,159)=T3;
  g1(104,160)=0.25;
  g1(105,159)=1;
  g1(105,252)=(-0.05);
  g1(105,253)=(-0.05);
  g1(105,254)=(-0.05);
  g1(105,255)=(-0.05);
  g1(105,256)=(-0.05);
  g1(105,257)=(-0.05);
  g1(105,258)=(-0.05);
  g1(105,259)=(-0.05);
  g1(105,260)=(-0.05);
  g1(105,261)=(-0.05);
  g1(105,262)=(-0.05);
  g1(105,263)=(-0.05);
  g1(105,264)=(-0.05);
  g1(105,265)=(-0.05);
  g1(105,266)=(-0.05);
  g1(105,267)=(-0.05);
  g1(105,268)=(-0.05);
  g1(105,269)=(-0.05);
  g1(105,270)=(-0.05);
  g1(105,271)=(-0.05);
  g1(106,160)=T3;
  g1(106,161)=1;
  g1(107,58)=1;
  g1(107,78)=T130*(-params(41));
  g1(107,79)=T130*params(41)*(cgamma__*cpie__-1);
  g1(107,83)=T130*(-params(41));
  g1(107,29)=T130;
  g1(107,119)=T3;
  g1(108,59)=1;
  g1(108,119)=(-(1/params(41)));
  g1(109,216)=T3;
  g1(109,162)=1;
  g1(110,233)=T3;
  g1(110,163)=1;
  g1(111,234)=T3;
  g1(111,164)=1;
  g1(112,235)=T3;
  g1(112,165)=1;
  g1(113,236)=T3;
  g1(113,166)=1;
  g1(114,237)=T3;
  g1(114,167)=1;
  g1(115,238)=T3;
  g1(115,168)=1;
  g1(116,239)=T3;
  g1(116,169)=1;
  g1(117,240)=T3;
  g1(117,170)=1;
  g1(118,241)=T3;
  g1(118,171)=1;
  g1(119,242)=T3;
  g1(119,172)=1;
  g1(120,243)=T3;
  g1(120,173)=1;
  g1(121,244)=T3;
  g1(121,174)=1;
  g1(122,245)=T3;
  g1(122,175)=1;
  g1(123,246)=T3;
  g1(123,176)=1;
  g1(124,247)=T3;
  g1(124,177)=1;
  g1(125,248)=T3;
  g1(125,178)=1;
  g1(126,249)=T3;
  g1(126,179)=1;
  g1(127,250)=T3;
  g1(127,180)=1;
  g1(128,251)=T3;
  g1(128,181)=1;
  g1(129,252)=T3;
  g1(129,182)=1;
  g1(130,253)=T3;
  g1(130,183)=1;
  g1(131,254)=T3;
  g1(131,184)=1;
  g1(132,255)=T3;
  g1(132,185)=1;
  g1(133,256)=T3;
  g1(133,186)=1;
  g1(134,257)=T3;
  g1(134,187)=1;
  g1(135,258)=T3;
  g1(135,188)=1;
  g1(136,259)=T3;
  g1(136,189)=1;
  g1(137,260)=T3;
  g1(137,190)=1;
  g1(138,261)=T3;
  g1(138,191)=1;
  g1(139,262)=T3;
  g1(139,192)=1;
  g1(140,263)=T3;
  g1(140,193)=1;
  g1(141,264)=T3;
  g1(141,194)=1;
  g1(142,265)=T3;
  g1(142,195)=1;
  g1(143,266)=T3;
  g1(143,196)=1;
  g1(144,267)=T3;
  g1(144,197)=1;
  g1(145,268)=T3;
  g1(145,198)=1;
  g1(146,269)=T3;
  g1(146,199)=1;
  g1(147,270)=T3;
  g1(147,200)=1;
  g1(148,11)=T3;
  g1(148,201)=1;
  g1(149,15)=T3;
  g1(149,202)=1;
  g1(150,45)=T3;
  g1(150,203)=1;
  g1(151,279)=T3;
  g1(151,204)=1;
  g1(152,280)=T3;
  g1(152,205)=1;
  g1(153,281)=T3;
  g1(153,206)=1;
  g1(154,282)=T3;
  g1(154,207)=1;
  g1(155,283)=T3;
  g1(155,208)=1;
  g1(156,284)=T3;
  g1(156,209)=1;
  g1(157,285)=T3;
  g1(157,210)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],157,84100);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],157,24389000);
end
end
end
end
