function [residual, g1, g2, g3] = testdynare_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 157, 1);

%
% Model equations
%

cgamma__ = 1+params(26)/100;
crealrate__ = 1+params(110)/100;
cbetabar__ = params(42)/crealrate__;
clandap__ = params(17);
cik__ = cgamma__*(1-(1-params(14))/cgamma__);
cikbar__ = 1-(1-params(14))/cgamma__;
cky__ = params(4)/cik__;
crk__ = params(14)+(params(43)/cbetabar__-1)/(1-params(50));
calfa__ = clandap__/params(17)*crk__*cky__;
clabshare__ = 1-calfa__;
cwly__ = clabshare__-params(51);
ctauwf__ = params(51)/cwly__;
ctauwh__ = params(52)/cwly__;
cnprofy__ = 1-clabshare__-params(14)*cky__;
ctaun__ = (params(5)-params(50)*cnprofy__)/cwly__;
ccy__ = 1-params(28)-params(4);
crkky__ = crk__*cky__;
cwhlc__ = cky__*crk__*(1-calfa__)*(1-ctauwh__-ctaun__)/(1+params(49))*1/params(33)/calfa__/ccy__;
cpie__ = 1+params(7)/100;
cr__ = crealrate__*cpie__;
conster__ = 100*(cr__-1);
cpbgov__ = (1+params(42)*params(40)/cr__-params(42))/(1-params(42)/cr__*(1-params(40)));
crbgovncr__ = 1;
cpdy__ = (-(crealrate__/cgamma__-1))*params(41);
cdy__ = params(41)*(1-1/(cgamma__*cpie__));
cmawpr__ = params(25)-params(10);
cmappr__ = params(24)-params(11);
cthetabgovsrgg__ = (-params(75))*(1-params(72));
cthetabgovsrtt__ = (-params(80))*(1-params(77));
cthetabgovsrt__ = params(85)*(1-params(82));
cthetabgovsrtauc__ = params(90)*(1-params(87));
cthetabgovsrtaun__ = params(95)*(1-params(92));
cthetabgovsrtauwh__ = params(100)*(1-params(97));
cthetabgovsrtauwf__ = params(105)*(1-params(102));
constedy__ = 100*cdy__;
T124 = crealrate__/cgamma__;
T130 = 1/(cgamma__*cpie__);
T204 = 1/(params(12)/(1-params(12)));
T234 = params(16)/cgamma__;
T235 = 1-T234;
T241 = params(15)*params(16)/cgamma__;
T263 = 1+params(40)/cpbgov__-params(40);
T271 = (1-params(42))/cpbgov__;
T294 = (1-params(40))/(cgamma__*cpie__);
T318 = (1-params(15))/T235;
T344 = cgamma__^2;
T346 = T344*params(13);
T366 = crealrate__*params(41)/cgamma__;
T400 = cthetabgovsrgg__/params(41);
T421 = cthetabgovsrtt__/params(41);
T440 = cthetabgovsrt__/params(41);
T459 = cthetabgovsrtauc__/params(41);
T478 = cthetabgovsrtaun__/params(41);
T497 = cthetabgovsrtauwh__/params(41);
T516 = cthetabgovsrtauwf__/params(41);
T588 = 1/(1+cbetabar__*cgamma__);
T706 = 1/(1+cbetabar__*cgamma__*params(30));
T720 = (1-params(31))*(1-cbetabar__*cgamma__*params(31))/params(31)/(1+(clandap__-1)*params(2));
T728 = cbetabar__*cgamma__/(1+cbetabar__*cgamma__);
T769 = (1-params(19))*(1-cbetabar__*cgamma__*params(19))/((1+cbetabar__*cgamma__)*params(19))*1/(1+(params(33)-1)*params(1));
T1061 = (1-params(45))*(1-cgamma__*cbetabar__*params(45))/params(45);
lhs =y(42);
rhs =y(26)-y(88);
residual(1)= lhs-rhs;
lhs =y(15);
rhs =calfa__*y(81)+(1-calfa__)*(y(90)+y(98));
residual(2)= lhs-rhs;
lhs =y(80);
rhs =y(81)*T204;
residual(3)= lhs-rhs;
lhs =y(81);
rhs =y(90)+y(98)+y(89)-y(82);
residual(4)= lhs-rhs;
lhs =y(82);
rhs =y(80)+y(83)-y(25);
residual(5)= lhs-rhs;
lhs =y(86);
rhs =params(42)*(y(86)+y(91)-params(15)*y(25)-y(16))-params(111)*(1-params(42))*y(74)/params(41);
residual(6)= lhs-rhs;
lhs =y(86)*T235;
rhs =(-params(15))*y(85)+T241*(y(85)-y(25))+y(89)*(params(15)-1)*cwhlc__-T235*y(96)/(1+params(49));
residual(7)= lhs-rhs;
lhs =y(73);
rhs =params(42)*(y(86)-params(15)*y(25)-y(86))/cr__*T263-params(42)*y(16)/cpbgov__+y(73)*params(42)*(1-params(40))/cr__-T271*(y(86)+params(111)*y(74)/params(41));
residual(8)= lhs-rhs;
lhs =y(86);
rhs =params(42)*crbgovncr__*(y(86)+y(72)-params(15)*y(25)-y(16))-(1-params(42))*params(111)*y(74)/params(41);
residual(9)= lhs-rhs;
lhs =y(71)-y(72);
rhs =(y(71)-y(72))*T294;
residual(10)= lhs-rhs;
lhs =y(88);
rhs =ccy__*y(85)+params(4)*y(87)+y(17)+params(29)*y(92)+y(80)*crkky__;
residual(11)= lhs-rhs;
lhs =y(88);
rhs =params(17)*(y(15)+calfa__*y(82)+(1-calfa__)*y(89));
residual(12)= lhs-rhs;
lhs =T318*(y(85)-T234*(y(85)-y(25)))+y(89)*(params(15)-1)*cwhlc__/T235+y(89)*params(32);
rhs =y(90)+y(86)-(y(102)+y(100))/(1-ctauwh__-ctaun__);
residual(13)= lhs-rhs;
lhs =y(83);
rhs =(1-cikbar__)*(y(83)-y(25))+y(87)*cikbar__+cikbar__*(1+cbetabar__*cgamma__)*T346*y(18);
residual(14)= lhs-rhs;
lhs =cnprofy__*y(79);
rhs =y(88)-cwly__*(y(98)+(1+ctauwf__)*(y(90)+y(89)))-y(80)*crkky__-params(14)*cky__*(y(83)-y(25));
residual(15)= lhs-rhs;
lhs =y(74);
rhs =params(29)*y(92)+T124*(y(74)-y(25))+y(71)*T366+params(53)*y(94)-(y(76)+y(88)*params(44)+cwly__*(y(98)+y(102)+y(100)+(y(90)+y(89))*(ctauwf__+ctauwh__+ctaun__))+ccy__*(y(96)+params(49)*y(85))+cnprofy__*(params(50)*y(79)+y(104)));
residual(16)= lhs-rhs;
lhs =y(93);
rhs =params(72)*y(93)+T400*(y(74)-y(75))+(1-params(73))*x(8)+params(73)*x(8);
residual(17)= lhs-rhs;
lhs =y(92);
rhs =y(93)+y(88)*params(74);
residual(18)= lhs-rhs;
lhs =y(95);
rhs =params(77)*y(95)+(y(74)-y(75))*T421+(1-params(78))*x(9)+params(78)*x(9);
residual(19)= lhs-rhs;
lhs =y(94);
rhs =y(95)+y(88)*params(79);
residual(20)= lhs-rhs;
lhs =y(77);
rhs =params(82)*y(77)+(y(74)-y(75))*T440+(1-params(83))*x(10)+params(83)*x(10);
residual(21)= lhs-rhs;
lhs =y(76);
rhs =y(77)+y(88)*params(84);
residual(22)= lhs-rhs;
lhs =y(97);
rhs =params(87)*y(97)+(y(74)-y(75))*T459+(1-params(88))*x(11)+params(88)*x(11);
residual(23)= lhs-rhs;
lhs =y(96);
rhs =y(97)+y(88)*params(89);
residual(24)= lhs-rhs;
lhs =y(101);
rhs =params(92)*y(101)+(y(74)-y(75))*T478+(1-params(93))*x(12)+params(93)*x(12);
residual(25)= lhs-rhs;
lhs =y(100);
rhs =y(101)+y(88)*params(94);
residual(26)= lhs-rhs;
lhs =y(103);
rhs =params(97)*y(103)+(y(74)-y(75))*T497+(1-params(98))*x(13)+params(98)*x(13);
residual(27)= lhs-rhs;
lhs =y(102);
rhs =y(103)+y(88)*params(99);
residual(28)= lhs-rhs;
lhs =y(99);
rhs =params(102)*y(99)+(y(74)-y(75))*T516+(1-params(103))*x(14)+params(103)*x(14);
residual(29)= lhs-rhs;
lhs =y(98);
rhs =y(99)+y(88)*params(104);
residual(30)= lhs-rhs;
residual(31) = y(104);
lhs =y(75);
rhs =y(68);
residual(32)= lhs-rhs;
lhs =y(78);
rhs =params(29)*y(92)-y(76)-params(53)*y(94)-cpdy__*y(88)-y(88)*params(44);
residual(33)= lhs-rhs;
lhs =y(33);
rhs =calfa__*y(36)+(1-calfa__)*(y(31)+y(56))-y(15);
residual(34)= lhs-rhs;
lhs =y(35);
rhs =T204*y(36);
residual(35)= lhs-rhs;
lhs =y(36);
rhs =y(56)+y(31)+y(40)-y(37);
residual(36)= lhs-rhs;
lhs =y(37);
rhs =y(35)+y(38)-y(25);
residual(37)= lhs-rhs;
lhs =y(39);
rhs =params(43)*(y(29)-params(15)*y(25))-y(29)+y(36)*(1-params(50))*cbetabar__*crk__+y(39)*cbetabar__*(1-params(14))-y(38)*(1-params(43))*params(112)-crk__*cbetabar__*(1-params(14))*y(60);
residual(38)= lhs-rhs;
lhs =y(28);
rhs =y(18)+T588*(y(28)+cbetabar__*cgamma__*y(28)+y(39)*1/T346-y(25)+y(25)*cbetabar__*cgamma__);
residual(39)= lhs-rhs;
lhs =y(87);
rhs =y(18)+T588*(y(25)*cbetabar__*cgamma__+y(87)+y(87)*cbetabar__*cgamma__+1/T346*y(84)-y(25));
residual(40)= lhs-rhs;
lhs =y(84);
rhs =params(43)*(y(86)-params(15)*y(25))-y(86)+y(81)*(1-params(50))*cbetabar__*crk__+cbetabar__*(1-params(14))*y(84)-y(83)*(1-params(43))*params(112)-y(104)*crk__*cbetabar__*(1-params(14));
residual(41)= lhs-rhs;
lhs =y(38);
rhs =(1-cikbar__)*(y(38)-y(25))+cikbar__*y(28)+y(18)*params(13)*cikbar__*(1+cbetabar__*cgamma__)*T344;
residual(42)= lhs-rhs;
lhs =y(29);
rhs =params(42)*(y(29)+y(43)-y(30)-params(15)*y(25)-y(16))-params(111)*(1-params(42))*y(66)/params(41);
residual(43)= lhs-rhs;
lhs =y(49);
rhs =T263*params(42)*(y(29)-params(15)*y(25)-y(29)-y(30))/cr__-params(42)*y(16)/cpbgov__+params(42)*(1-params(40))/cr__*y(49)-T271*(y(29)+params(111)*y(66)/params(41));
residual(44)= lhs-rhs;
lhs =y(29);
rhs =params(42)*crbgovncr__*(y(29)+y(48)-y(30)-params(15)*y(25)-y(16))-(1-params(42))*params(111)*y(66)/params(41);
residual(45)= lhs-rhs;
lhs =y(47)-y(48);
rhs =T294*(y(47)-y(48));
residual(46)= lhs-rhs;
lhs =T235*y(29);
rhs =(-params(15))*y(27)+T241*(y(27)-y(25))+(params(15)-1)*cwhlc__*y(40)-T235*y(52)/(1+params(49));
residual(47)= lhs-rhs;
lhs =y(26);
rhs =y(17)+ccy__*y(27)+params(4)*y(28)+params(29)*y(50)+crkky__*y(35);
residual(48)= lhs-rhs;
lhs =y(105);
rhs =y(17)+ccy__*y(27)+params(4)*y(28)+params(29)*y(50);
residual(49)= lhs-rhs;
lhs =y(26);
rhs =params(17)*(y(15)+calfa__*y(37)+(1-calfa__)*y(40));
residual(50)= lhs-rhs;
lhs =y(30)-y(24);
rhs =T706*(cbetabar__*cgamma__*(y(30)-y(24))+(y(30)-y(24))*params(30)+y(33)*T720)+y(20);
residual(51)= lhs-rhs;
lhs =y(31);
rhs =y(31)*T588+y(31)*T728+y(30)*params(18)/(1+cbetabar__*cgamma__)-y(30)*(1+cbetabar__*cgamma__*params(18))/(1+cbetabar__*cgamma__)+T588*(y(34)+y(25)*cbetabar__*cgamma__-y(25)-cbetabar__*cgamma__*y(34))+y(30)*T728-y(24)*cbetabar__*cgamma__*(1-params(18))/(1+cbetabar__*cgamma__)+y(24)*(1-params(18))/(1+cbetabar__*cgamma__)+T769*(y(32)-y(31))+y(21);
residual(52)= lhs-rhs;
lhs =y(34);
rhs =y(25);
residual(53)= lhs-rhs;
lhs =T318*(y(27)-T234*(y(27)-y(25)))+(params(15)-1)*cwhlc__/T235*y(40)+params(32)*y(40);
rhs =y(29)+y(32)-(y(54)+y(58))/(1-ctauwh__-ctaun__);
residual(54)= lhs-rhs;
lhs =y(43)-y(24);
rhs =(1-x(19))*((y(30)-y(24))*params(34)*(1-params(37))+(y(26)-y(88))*(1-params(37))*params(36)+params(35)*(y(88)+y(26)-y(88)-y(26))+(y(43)-y(24))*params(37)+y(19))-x(19)*x(18)+y(10);
residual(55)= lhs-rhs;
lhs =y(24)-y(24)*0.999;
rhs =x(16)+(y(24)-y(24)*0.999)*params(23);
residual(56)= lhs-rhs;
lhs =y(10);
rhs =y(10)*params(71)+x(17);
residual(57)= lhs-rhs;
lhs =y(14);
rhs =y(10)+y(24)+y(19)-y(24)*params(37)-y(24)*params(34)*(1-params(37));
residual(58)= lhs-rhs;
lhs =y(11);
rhs =y(14);
residual(59)= lhs-rhs;
lhs =y(15);
rhs =y(15)*params(38)+x(1);
residual(60)= lhs-rhs;
lhs =y(16);
rhs =y(16)*params(39)+x(2);
residual(61)= lhs-rhs;
lhs =y(17);
rhs =y(17)*params(20)+x(3)+x(1)*params(3);
residual(62)= lhs-rhs;
lhs =y(18);
rhs =y(18)*params(21)+x(4);
residual(63)= lhs-rhs;
lhs =y(19);
rhs =y(19)*params(22)+x(5);
residual(64)= lhs-rhs;
lhs =y(20);
rhs =params(24)*y(20)+y(23)-y(23)*cmappr__;
residual(65)= lhs-rhs;
lhs =y(23);
rhs =x(6);
residual(66)= lhs-rhs;
lhs =y(21);
rhs =params(25)*y(21)+y(22)-y(22)*cmawpr__;
residual(67)= lhs-rhs;
lhs =y(22);
rhs =x(7);
residual(68)= lhs-rhs;
residual(69) = y(25);
lhs =cnprofy__*y(67);
rhs =y(26)-cwly__*(y(56)+(1+ctauwf__)*(y(31)+y(40)))-crkky__*y(35)-params(14)*cky__*(y(38)-y(25));
residual(70)= lhs-rhs;
lhs =y(66);
rhs =params(29)*y(50)+T124*(y(66)-y(25))+T366*(y(47)-y(30))+params(53)*y(63)-(y(61)+y(26)*params(44)+cwly__*(y(56)+y(58)+y(54)+(ctauwf__+ctauwh__+ctaun__)*(y(31)+y(40)))+ccy__*(y(52)+params(49)*y(27))+cnprofy__*(y(60)+params(50)*y(67)));
residual(71)= lhs-rhs;
lhs =y(51);
rhs =(1-params(73))*x(8)+params(72)*y(51)+T400*(y(66)-y(68))+params(73)*x(8);
residual(72)= lhs-rhs;
lhs =y(50);
rhs =y(51)+y(26)*params(74);
residual(73)= lhs-rhs;
lhs =y(64);
rhs =(1-params(78))*x(9)+params(77)*y(64)+T421*(y(66)-y(68))+params(78)*x(9);
residual(74)= lhs-rhs;
lhs =y(63);
rhs =y(64)+y(26)*params(79);
residual(75)= lhs-rhs;
lhs =y(62);
rhs =(1-params(83))*x(10)+params(82)*y(62)+T440*(y(66)-y(68))+params(83)*x(10);
residual(76)= lhs-rhs;
lhs =y(61);
rhs =y(62)+y(26)*params(84);
residual(77)= lhs-rhs;
lhs =y(53);
rhs =(1-params(88))*x(11)+params(87)*y(53)+T459*(y(66)-y(68))+params(88)*x(11);
residual(78)= lhs-rhs;
lhs =y(52);
rhs =y(53)+y(26)*params(89);
residual(79)= lhs-rhs;
lhs =y(59);
rhs =(1-params(93))*x(12)+params(92)*y(59)+T478*(y(66)-y(68))+params(93)*x(12);
residual(80)= lhs-rhs;
lhs =y(58);
rhs =y(59)+y(26)*params(94);
residual(81)= lhs-rhs;
lhs =y(55);
rhs =(1-params(98))*x(13)+params(97)*y(55)+T497*(y(66)-y(68))+params(98)*x(13);
residual(82)= lhs-rhs;
lhs =y(54);
rhs =y(55)+y(26)*params(99);
residual(83)= lhs-rhs;
lhs =y(57);
rhs =(1-params(103))*x(14)+params(102)*y(57)+T516*(y(66)-y(68))+params(103)*x(14);
residual(84)= lhs-rhs;
lhs =y(56);
rhs =y(57)+y(26)*params(104);
residual(85)= lhs-rhs;
residual(86) = y(60);
lhs =y(65);
rhs =params(29)*y(50)+params(53)*y(63)-(y(61)+y(26)*params(44)+cwly__*(y(56)+y(58)+y(54)+(ctauwf__+ctauwh__+ctaun__)*(y(31)+y(40)))+ccy__*(y(52)+params(49)*y(27))+cnprofy__*(y(60)+params(50)*y(67)))-cpdy__*y(26);
residual(87)= lhs-rhs;
residual(88) = y(68);
lhs =y(70);
rhs =y(70)*params(107)+y(69);
residual(89)= lhs-rhs;
lhs =y(69);
rhs =y(69)*params(108)+x(15);
residual(90)= lhs-rhs;
lhs =y(46);
rhs =y(30)+y(30)+y(30)+y(30);
residual(91)= lhs-rhs;
lhs =y(45);
rhs =4*y(30);
residual(92)= lhs-rhs;
lhs =y(44);
rhs =4*y(43);
residual(93)= lhs-rhs;
lhs =y(4);
rhs =params(26)+cgamma__*y(25);
residual(94)= lhs-rhs;
lhs =y(7);
rhs =params(26)+y(25);
residual(95)= lhs-rhs;
lhs =y(8);
rhs =params(26)+y(25);
residual(96)= lhs-rhs;
lhs =y(3);
rhs =params(7)+y(30);
residual(97)= lhs-rhs;
lhs =y(2);
rhs =4*(y(43)+conster__);
residual(98)= lhs-rhs;
lhs =y(9);
rhs =params(26)+y(25);
residual(99)= lhs-rhs;
lhs =0;
rhs =T1061*(y(40)-y(41));
residual(100)= lhs-rhs;
lhs =y(1);
rhs =y(41)+params(6);
residual(101)= lhs-rhs;
lhs =y(13);
rhs =4*(y(43)+conster__);
residual(102)= lhs-rhs;
lhs =y(12);
rhs =4*(y(43)+conster__);
residual(103)= lhs-rhs;
lhs =y(107)/4;
rhs =y(106)+params(8);
residual(104)= lhs-rhs;
lhs =y(106);
rhs =0.05*(y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30)+y(30));
residual(105)= lhs-rhs;
lhs =y(108);
rhs =y(107);
residual(106)= lhs-rhs;
lhs =y(5);
rhs =y(66)+constedy__-T130*(y(66)+params(41)*(y(26)*(cgamma__*cpie__-1)-(y(25)+y(30))));
residual(107)= lhs-rhs;
lhs =y(6);
rhs =y(66)/params(41)+params(48);
residual(108)= lhs-rhs;
lhs =y(109);
rhs =y(30);
residual(109)= lhs-rhs;
lhs =y(110);
rhs =y(30);
residual(110)= lhs-rhs;
lhs =y(111);
rhs =y(30);
residual(111)= lhs-rhs;
lhs =y(112);
rhs =y(30);
residual(112)= lhs-rhs;
lhs =y(113);
rhs =y(30);
residual(113)= lhs-rhs;
lhs =y(114);
rhs =y(30);
residual(114)= lhs-rhs;
lhs =y(115);
rhs =y(30);
residual(115)= lhs-rhs;
lhs =y(116);
rhs =y(30);
residual(116)= lhs-rhs;
lhs =y(117);
rhs =y(30);
residual(117)= lhs-rhs;
lhs =y(118);
rhs =y(30);
residual(118)= lhs-rhs;
lhs =y(119);
rhs =y(30);
residual(119)= lhs-rhs;
lhs =y(120);
rhs =y(30);
residual(120)= lhs-rhs;
lhs =y(121);
rhs =y(30);
residual(121)= lhs-rhs;
lhs =y(122);
rhs =y(30);
residual(122)= lhs-rhs;
lhs =y(123);
rhs =y(30);
residual(123)= lhs-rhs;
lhs =y(124);
rhs =y(30);
residual(124)= lhs-rhs;
lhs =y(125);
rhs =y(30);
residual(125)= lhs-rhs;
lhs =y(126);
rhs =y(30);
residual(126)= lhs-rhs;
lhs =y(127);
rhs =y(30);
residual(127)= lhs-rhs;
lhs =y(128);
rhs =y(30);
residual(128)= lhs-rhs;
lhs =y(129);
rhs =y(30);
residual(129)= lhs-rhs;
lhs =y(130);
rhs =y(30);
residual(130)= lhs-rhs;
lhs =y(131);
rhs =y(30);
residual(131)= lhs-rhs;
lhs =y(132);
rhs =y(30);
residual(132)= lhs-rhs;
lhs =y(133);
rhs =y(30);
residual(133)= lhs-rhs;
lhs =y(134);
rhs =y(30);
residual(134)= lhs-rhs;
lhs =y(135);
rhs =y(30);
residual(135)= lhs-rhs;
lhs =y(136);
rhs =y(30);
residual(136)= lhs-rhs;
lhs =y(137);
rhs =y(30);
residual(137)= lhs-rhs;
lhs =y(138);
rhs =y(30);
residual(138)= lhs-rhs;
lhs =y(139);
rhs =y(30);
residual(139)= lhs-rhs;
lhs =y(140);
rhs =y(30);
residual(140)= lhs-rhs;
lhs =y(141);
rhs =y(30);
residual(141)= lhs-rhs;
lhs =y(142);
rhs =y(30);
residual(142)= lhs-rhs;
lhs =y(143);
rhs =y(30);
residual(143)= lhs-rhs;
lhs =y(144);
rhs =y(30);
residual(144)= lhs-rhs;
lhs =y(145);
rhs =y(30);
residual(145)= lhs-rhs;
lhs =y(146);
rhs =y(30);
residual(146)= lhs-rhs;
lhs =y(147);
rhs =y(30);
residual(147)= lhs-rhs;
lhs =y(148);
rhs =y(24);
residual(148)= lhs-rhs;
lhs =y(149);
rhs =y(30);
residual(149)= lhs-rhs;
lhs =y(150);
rhs =y(30);
residual(150)= lhs-rhs;
lhs =y(151);
rhs =x(8);
residual(151)= lhs-rhs;
lhs =y(152);
rhs =x(9);
residual(152)= lhs-rhs;
lhs =y(153);
rhs =x(10);
residual(153)= lhs-rhs;
lhs =y(154);
rhs =x(11);
residual(154)= lhs-rhs;
lhs =y(155);
rhs =x(12);
residual(155)= lhs-rhs;
lhs =y(156);
rhs =x(13);
residual(156)= lhs-rhs;
lhs =y(157);
rhs =x(14);
residual(157)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(157, 157);

  %
  % Jacobian matrix
  %

T3 = (-1);
T1451 = (-(T263*params(42)*(-params(15))/cr__));
T1568 = 1/(1-ctauwh__-ctaun__);
  g1(1,26)=T3;
  g1(1,42)=1;
  g1(1,88)=1;
  g1(2,15)=1;
  g1(2,81)=(-calfa__);
  g1(2,90)=(-(1-calfa__));
  g1(2,98)=(-(1-calfa__));
  g1(3,80)=1;
  g1(3,81)=(-T204);
  g1(4,81)=1;
  g1(4,82)=1;
  g1(4,89)=T3;
  g1(4,90)=T3;
  g1(4,98)=T3;
  g1(5,25)=1;
  g1(5,80)=T3;
  g1(5,82)=1;
  g1(5,83)=T3;
  g1(6,16)=params(42);
  g1(6,25)=(-(params(42)*(-params(15))));
  g1(6,74)=params(111)*(1-params(42))*1/params(41);
  g1(6,86)=1-params(42);
  g1(6,91)=(-params(42));
  g1(7,25)=T241;
  g1(7,85)=(-((-params(15))+T241));
  g1(7,86)=T235;
  g1(7,89)=(-((params(15)-1)*cwhlc__));
  g1(7,96)=T235/(1+params(49));
  g1(8,16)=params(42)/cpbgov__;
  g1(8,25)=T1451;
  g1(8,73)=1-params(42)*(1-params(40))/cr__;
  g1(8,74)=T271*params(111)/params(41);
  g1(8,86)=T271;
  g1(9,16)=params(42)*crbgovncr__;
  g1(9,25)=(-((-params(15))*params(42)*crbgovncr__));
  g1(9,72)=(-(params(42)*crbgovncr__));
  g1(9,74)=(1-params(42))*params(111)/params(41);
  g1(9,86)=1-params(42)*crbgovncr__;
  g1(10,71)=1-T294;
  g1(10,72)=T3-(-T294);
  g1(11,17)=T3;
  g1(11,80)=(-crkky__);
  g1(11,85)=(-ccy__);
  g1(11,87)=(-params(4));
  g1(11,88)=1;
  g1(11,92)=(-params(29));
  g1(12,15)=(-params(17));
  g1(12,82)=(-(params(17)*calfa__));
  g1(12,88)=1;
  g1(12,89)=(-(params(17)*(1-calfa__)));
  g1(13,25)=T234*T318;
  g1(13,85)=T235*T318;
  g1(13,86)=T3;
  g1(13,89)=(params(15)-1)*cwhlc__/T235+params(32);
  g1(13,90)=T3;
  g1(13,100)=T1568;
  g1(13,102)=T1568;
  g1(14,18)=(-(cikbar__*(1+cbetabar__*cgamma__)*T346));
  g1(14,25)=1-cikbar__;
  g1(14,83)=1-(1-cikbar__);
  g1(14,87)=(-cikbar__);
  g1(15,25)=(-(params(14)*cky__));
  g1(15,79)=cnprofy__;
  g1(15,80)=crkky__;
  g1(15,83)=params(14)*cky__;
  g1(15,88)=T3;
  g1(15,89)=cwly__*(1+ctauwf__);
  g1(15,90)=cwly__*(1+ctauwf__);
  g1(15,98)=cwly__;
  g1(16,25)=T124;
  g1(16,71)=(-T366);
  g1(16,74)=1-T124;
  g1(16,76)=1;
  g1(16,79)=params(50)*cnprofy__;
  g1(16,85)=params(49)*ccy__;
  g1(16,88)=params(44);
  g1(16,89)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(16,90)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(16,92)=(-params(29));
  g1(16,94)=(-params(53));
  g1(16,96)=ccy__;
  g1(16,98)=cwly__;
  g1(16,100)=cwly__;
  g1(16,102)=cwly__;
  g1(16,104)=cnprofy__;
  g1(17,74)=(-T400);
  g1(17,75)=T400;
  g1(17,93)=1-params(72);
  g1(18,88)=(-params(74));
  g1(18,92)=1;
  g1(18,93)=T3;
  g1(19,74)=(-T421);
  g1(19,75)=T421;
  g1(19,95)=1-params(77);
  g1(20,88)=(-params(79));
  g1(20,94)=1;
  g1(20,95)=T3;
  g1(21,74)=(-T440);
  g1(21,75)=T440;
  g1(21,77)=1-params(82);
  g1(22,76)=1;
  g1(22,77)=T3;
  g1(22,88)=(-params(84));
  g1(23,74)=(-T459);
  g1(23,75)=T459;
  g1(23,97)=1-params(87);
  g1(24,88)=(-params(89));
  g1(24,96)=1;
  g1(24,97)=T3;
  g1(25,74)=(-T478);
  g1(25,75)=T478;
  g1(25,101)=1-params(92);
  g1(26,88)=(-params(94));
  g1(26,100)=1;
  g1(26,101)=T3;
  g1(27,74)=(-T497);
  g1(27,75)=T497;
  g1(27,103)=1-params(97);
  g1(28,88)=(-params(99));
  g1(28,102)=1;
  g1(28,103)=T3;
  g1(29,74)=(-T516);
  g1(29,75)=T516;
  g1(29,99)=1-params(102);
  g1(30,88)=(-params(104));
  g1(30,98)=1;
  g1(30,99)=T3;
  g1(31,104)=1;
  g1(32,68)=T3;
  g1(32,75)=1;
  g1(33,76)=1;
  g1(33,78)=1;
  g1(33,88)=(-((-cpdy__)-params(44)));
  g1(33,92)=(-params(29));
  g1(33,94)=params(53);
  g1(34,15)=1;
  g1(34,31)=(-(1-calfa__));
  g1(34,33)=1;
  g1(34,36)=(-calfa__);
  g1(34,56)=(-(1-calfa__));
  g1(35,35)=1;
  g1(35,36)=(-T204);
  g1(36,31)=T3;
  g1(36,36)=1;
  g1(36,37)=1;
  g1(36,40)=T3;
  g1(36,56)=T3;
  g1(37,25)=1;
  g1(37,35)=T3;
  g1(37,37)=1;
  g1(37,38)=T3;
  g1(38,25)=(-(params(43)*(-params(15))));
  g1(38,29)=(-(params(43)-1));
  g1(38,36)=(-((1-params(50))*cbetabar__*crk__));
  g1(38,38)=(1-params(43))*params(112);
  g1(38,39)=1-cbetabar__*(1-params(14));
  g1(38,60)=crk__*cbetabar__*(1-params(14));
  g1(39,18)=T3;
  g1(39,25)=(-(T588*(T3+cbetabar__*cgamma__)));
  g1(39,28)=1-(1+cbetabar__*cgamma__)*T588;
  g1(39,39)=(-(T588*1/T346));
  g1(40,18)=T3;
  g1(40,25)=(-(T588*(cbetabar__*cgamma__-1)));
  g1(40,84)=(-(T588*1/T346));
  g1(40,87)=1-(1+cbetabar__*cgamma__)*T588;
  g1(41,25)=(-(params(43)*(-params(15))));
  g1(41,81)=(-((1-params(50))*cbetabar__*crk__));
  g1(41,83)=(1-params(43))*params(112);
  g1(41,84)=1-cbetabar__*(1-params(14));
  g1(41,86)=(-(params(43)-1));
  g1(41,104)=crk__*cbetabar__*(1-params(14));
  g1(42,18)=(-(params(13)*cikbar__*(1+cbetabar__*cgamma__)*T344));
  g1(42,25)=1-cikbar__;
  g1(42,28)=(-cikbar__);
  g1(42,38)=1-(1-cikbar__);
  g1(43,16)=params(42);
  g1(43,25)=(-(params(42)*(-params(15))));
  g1(43,29)=1-params(42);
  g1(43,30)=params(42);
  g1(43,43)=(-params(42));
  g1(43,66)=params(111)*(1-params(42))*1/params(41);
  g1(44,16)=params(42)/cpbgov__;
  g1(44,25)=T1451;
  g1(44,29)=T271;
  g1(44,30)=(-(T263*(-params(42))/cr__));
  g1(44,49)=1-params(42)*(1-params(40))/cr__;
  g1(44,66)=T271*params(111)/params(41);
  g1(45,16)=params(42)*crbgovncr__;
  g1(45,25)=(-((-params(15))*params(42)*crbgovncr__));
  g1(45,29)=1-params(42)*crbgovncr__;
  g1(45,30)=params(42)*crbgovncr__;
  g1(45,48)=(-(params(42)*crbgovncr__));
  g1(45,66)=(1-params(42))*params(111)/params(41);
  g1(46,47)=1-T294;
  g1(46,48)=T3-(-T294);
  g1(47,25)=T241;
  g1(47,27)=(-((-params(15))+T241));
  g1(47,29)=T235;
  g1(47,40)=(-((params(15)-1)*cwhlc__));
  g1(47,52)=T235/(1+params(49));
  g1(48,17)=T3;
  g1(48,26)=1;
  g1(48,27)=(-ccy__);
  g1(48,28)=(-params(4));
  g1(48,35)=(-crkky__);
  g1(48,50)=(-params(29));
  g1(49,17)=T3;
  g1(49,27)=(-ccy__);
  g1(49,28)=(-params(4));
  g1(49,50)=(-params(29));
  g1(49,105)=1;
  g1(50,15)=(-params(17));
  g1(50,26)=1;
  g1(50,37)=(-(params(17)*calfa__));
  g1(50,40)=(-(params(17)*(1-calfa__)));
  g1(51,20)=T3;
  g1(51,24)=T3-T706*((-(cbetabar__*cgamma__))-params(30));
  g1(51,30)=1-T706*(cbetabar__*cgamma__+params(30));
  g1(51,33)=(-(T706*T720));
  g1(52,21)=T3;
  g1(52,24)=(-((1-params(18))/(1+cbetabar__*cgamma__)+(-(cbetabar__*cgamma__*(1-params(18))/(1+cbetabar__*cgamma__)))));
  g1(52,25)=(-(T588*(cbetabar__*cgamma__-1)));
  g1(52,30)=(-(T728+params(18)/(1+cbetabar__*cgamma__)-(1+cbetabar__*cgamma__*params(18))/(1+cbetabar__*cgamma__)));
  g1(52,31)=1-(T588+T728-T769);
  g1(52,32)=(-T769);
  g1(52,34)=(-(T588*(1-cbetabar__*cgamma__)));
  g1(53,25)=T3;
  g1(53,34)=1;
  g1(54,25)=T234*T318;
  g1(54,27)=T235*T318;
  g1(54,29)=T3;
  g1(54,32)=T3;
  g1(54,40)=(params(15)-1)*cwhlc__/T235+params(32);
  g1(54,54)=T1568;
  g1(54,58)=T1568;
  g1(55,10)=T3;
  g1(55,19)=(-(1-x(19)));
  g1(55,24)=T3-(1-x(19))*((-(params(34)*(1-params(37))))-params(37));
  g1(55,26)=(-((1-x(19))*(1-params(37))*params(36)));
  g1(55,30)=(-((1-x(19))*params(34)*(1-params(37))));
  g1(55,43)=1-(1-x(19))*params(37);
  g1(55,88)=(-((1-x(19))*(-((1-params(37))*params(36)))));
  g1(56,24)=0.001000000000000001-params(23)*0.001000000000000001;
  g1(57,10)=1-params(71);
  g1(58,10)=T3;
  g1(58,14)=1;
  g1(58,19)=T3;
  g1(58,24)=(-(1-params(37)-params(34)*(1-params(37))));
  g1(59,11)=1;
  g1(59,14)=T3;
  g1(60,15)=1-params(38);
  g1(61,16)=1-params(39);
  g1(62,17)=1-params(20);
  g1(63,18)=1-params(21);
  g1(64,19)=1-params(22);
  g1(65,20)=1-params(24);
  g1(65,23)=(-(1-cmappr__));
  g1(66,23)=1;
  g1(67,21)=1-params(25);
  g1(67,22)=(-(1-cmawpr__));
  g1(68,22)=1;
  g1(69,25)=1;
  g1(70,25)=(-(params(14)*cky__));
  g1(70,26)=T3;
  g1(70,31)=cwly__*(1+ctauwf__);
  g1(70,35)=crkky__;
  g1(70,38)=params(14)*cky__;
  g1(70,40)=cwly__*(1+ctauwf__);
  g1(70,56)=cwly__;
  g1(70,67)=cnprofy__;
  g1(71,25)=T124;
  g1(71,26)=params(44);
  g1(71,27)=params(49)*ccy__;
  g1(71,30)=T366;
  g1(71,31)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(71,40)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(71,47)=(-T366);
  g1(71,50)=(-params(29));
  g1(71,52)=ccy__;
  g1(71,54)=cwly__;
  g1(71,56)=cwly__;
  g1(71,58)=cwly__;
  g1(71,60)=cnprofy__;
  g1(71,61)=1;
  g1(71,63)=(-params(53));
  g1(71,66)=1-T124;
  g1(71,67)=params(50)*cnprofy__;
  g1(72,51)=1-params(72);
  g1(72,66)=(-T400);
  g1(72,68)=T400;
  g1(73,26)=(-params(74));
  g1(73,50)=1;
  g1(73,51)=T3;
  g1(74,64)=1-params(77);
  g1(74,66)=(-T421);
  g1(74,68)=T421;
  g1(75,26)=(-params(79));
  g1(75,63)=1;
  g1(75,64)=T3;
  g1(76,62)=1-params(82);
  g1(76,66)=(-T440);
  g1(76,68)=T440;
  g1(77,26)=(-params(84));
  g1(77,61)=1;
  g1(77,62)=T3;
  g1(78,53)=1-params(87);
  g1(78,66)=(-T459);
  g1(78,68)=T459;
  g1(79,26)=(-params(89));
  g1(79,52)=1;
  g1(79,53)=T3;
  g1(80,59)=1-params(92);
  g1(80,66)=(-T478);
  g1(80,68)=T478;
  g1(81,26)=(-params(94));
  g1(81,58)=1;
  g1(81,59)=T3;
  g1(82,55)=1-params(97);
  g1(82,66)=(-T497);
  g1(82,68)=T497;
  g1(83,26)=(-params(99));
  g1(83,54)=1;
  g1(83,55)=T3;
  g1(84,57)=1-params(102);
  g1(84,66)=(-T516);
  g1(84,68)=T516;
  g1(85,26)=(-params(104));
  g1(85,56)=1;
  g1(85,57)=T3;
  g1(86,60)=1;
  g1(87,26)=(-((-params(44))-cpdy__));
  g1(87,27)=params(49)*ccy__;
  g1(87,31)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(87,40)=cwly__*(ctauwf__+ctauwh__+ctaun__);
  g1(87,50)=(-params(29));
  g1(87,52)=ccy__;
  g1(87,54)=cwly__;
  g1(87,56)=cwly__;
  g1(87,58)=cwly__;
  g1(87,60)=cnprofy__;
  g1(87,61)=1;
  g1(87,63)=(-params(53));
  g1(87,65)=1;
  g1(87,67)=params(50)*cnprofy__;
  g1(88,68)=1;
  g1(89,69)=T3;
  g1(89,70)=1-params(107);
  g1(90,69)=1-params(108);
  g1(91,30)=(-4);
  g1(91,46)=1;
  g1(92,30)=(-4);
  g1(92,45)=1;
  g1(93,43)=(-4);
  g1(93,44)=1;
  g1(94,4)=1;
  g1(94,25)=(-cgamma__);
  g1(95,7)=1;
  g1(95,25)=T3;
  g1(96,8)=1;
  g1(96,25)=T3;
  g1(97,3)=1;
  g1(97,30)=T3;
  g1(98,2)=1;
  g1(98,43)=(-4);
  g1(99,9)=1;
  g1(99,25)=T3;
  g1(100,40)=(-T1061);
  g1(100,41)=T1061;
  g1(101,1)=1;
  g1(101,41)=T3;
  g1(102,13)=1;
  g1(102,43)=(-4);
  g1(103,12)=1;
  g1(103,43)=(-4);
  g1(104,106)=T3;
  g1(104,107)=0.25;
  g1(105,30)=T3;
  g1(105,106)=1;
  g1(106,107)=T3;
  g1(106,108)=1;
  g1(107,5)=1;
  g1(107,25)=T130*(-params(41));
  g1(107,26)=T130*params(41)*(cgamma__*cpie__-1);
  g1(107,30)=T130*(-params(41));
  g1(107,66)=(-(1-T130));
  g1(108,6)=1;
  g1(108,66)=(-(1/params(41)));
  g1(109,30)=T3;
  g1(109,109)=1;
  g1(110,30)=T3;
  g1(110,110)=1;
  g1(111,30)=T3;
  g1(111,111)=1;
  g1(112,30)=T3;
  g1(112,112)=1;
  g1(113,30)=T3;
  g1(113,113)=1;
  g1(114,30)=T3;
  g1(114,114)=1;
  g1(115,30)=T3;
  g1(115,115)=1;
  g1(116,30)=T3;
  g1(116,116)=1;
  g1(117,30)=T3;
  g1(117,117)=1;
  g1(118,30)=T3;
  g1(118,118)=1;
  g1(119,30)=T3;
  g1(119,119)=1;
  g1(120,30)=T3;
  g1(120,120)=1;
  g1(121,30)=T3;
  g1(121,121)=1;
  g1(122,30)=T3;
  g1(122,122)=1;
  g1(123,30)=T3;
  g1(123,123)=1;
  g1(124,30)=T3;
  g1(124,124)=1;
  g1(125,30)=T3;
  g1(125,125)=1;
  g1(126,30)=T3;
  g1(126,126)=1;
  g1(127,30)=T3;
  g1(127,127)=1;
  g1(128,30)=T3;
  g1(128,128)=1;
  g1(129,30)=T3;
  g1(129,129)=1;
  g1(130,30)=T3;
  g1(130,130)=1;
  g1(131,30)=T3;
  g1(131,131)=1;
  g1(132,30)=T3;
  g1(132,132)=1;
  g1(133,30)=T3;
  g1(133,133)=1;
  g1(134,30)=T3;
  g1(134,134)=1;
  g1(135,30)=T3;
  g1(135,135)=1;
  g1(136,30)=T3;
  g1(136,136)=1;
  g1(137,30)=T3;
  g1(137,137)=1;
  g1(138,30)=T3;
  g1(138,138)=1;
  g1(139,30)=T3;
  g1(139,139)=1;
  g1(140,30)=T3;
  g1(140,140)=1;
  g1(141,30)=T3;
  g1(141,141)=1;
  g1(142,30)=T3;
  g1(142,142)=1;
  g1(143,30)=T3;
  g1(143,143)=1;
  g1(144,30)=T3;
  g1(144,144)=1;
  g1(145,30)=T3;
  g1(145,145)=1;
  g1(146,30)=T3;
  g1(146,146)=1;
  g1(147,30)=T3;
  g1(147,147)=1;
  g1(148,24)=T3;
  g1(148,148)=1;
  g1(149,30)=T3;
  g1(149,149)=1;
  g1(150,30)=T3;
  g1(150,150)=1;
  g1(151,151)=1;
  g1(152,152)=1;
  g1(153,153)=1;
  g1(154,154)=1;
  g1(155,155)=1;
  g1(156,156)=1;
  g1(157,157)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],157,24649);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],157,3869893);
end
end
end
end
